@@ -6,7 +6,7 @@ from suanpan import g
 from suanpan.proxy import Proxy
 
 if typing.TYPE_CHECKING:
-    from suanpan.types import AppT
+    from suanpan.stypes import AppT
 
 
 class App(Proxy):
